pub struct LoginFinishedS2c<'a> {
pub uuid: Uuid,
pub username: Bounded<&'a str, 16>,
pub properties: Cow<'a, [Property<&'a str>]>,
}Expand description
Sent by the server to the client to send the game profile of the player. This packet is sent after the client has successfully logged in. This packet is used to send data about the player such as their UUID, username, skin, and cape.
Fields
uuid: Uuidusername: Bounded<&'a str, 16>properties: Cow<'a, [Property<&'a str>]>Trait Implementations
Sourceimpl<'a> Clone for LoginFinishedS2c<'a>
impl<'a> Clone for LoginFinishedS2c<'a>
Sourcefn clone(&self) -> LoginFinishedS2c<'a>
fn clone(&self) -> LoginFinishedS2c<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for LoginFinishedS2c<'a>
impl<'a> Debug for LoginFinishedS2c<'a>
Sourceimpl<'a> Decode<'a> for LoginFinishedS2c<'a>
impl<'a> Decode<'a> for LoginFinishedS2c<'a>
Sourceimpl<'a> Encode for LoginFinishedS2c<'a>
impl<'a> Encode for LoginFinishedS2c<'a>
Sourceimpl<'a> Packet for LoginFinishedS2c<'a>
impl<'a> Packet for LoginFinishedS2c<'a>
Sourceconst ID: i32 = ::chunkedge_protocol::packet_id::LOGIN_LOGIN_FINISHED_S2C
const ID: i32 = ::chunkedge_protocol::packet_id::LOGIN_LOGIN_FINISHED_S2C
The leading
VarInt ID of this packet.Sourceconst SIDE: PacketSide = ::chunkedge_protocol::PacketSide::Clientbound
const SIDE: PacketSide = ::chunkedge_protocol::PacketSide::Clientbound
The side this packet is intended for.
Sourceconst STATE: PacketState = PacketState::Login
const STATE: PacketState = PacketState::Login
The state in which this packet is used.