LoginFinishedS2c

Struct LoginFinishedS2c 

pub struct LoginFinishedS2c<'a> {
    pub uuid: Uuid,
    pub username: Bounded<&'a str, 16>,
    pub properties: Cow<'a, [Property<&'a str>]>,
}
Sent by the server to the client to send the game profile of the player. This packet is sent after the client has successfully logged in. This packet is used to send data about the player such as their UUID, username, skin, and cape.

Fields

uuid: Uuidusername: Bounded<&'a str, 16>properties: Cow<'a, [Property<&'a str>]>